@@ -97,7 +97,7 @@ forest.multisimsum <- function(obj, sstat, par = NULL, by = NULL, target = NULL,
   gg <- gg +
     ggplot2::geom_hline(yintercept = target, linetype = gpars.ok$target.shape, colour = gpars.ok$target.colour) +
     ggplot2::geom_point() +
-    ggplot2::labs(x = sstat)
+    ggplot2::labs(y = sstat)
   # Add 'confidence intervals' if mcse are available
   if (obj[["mcse"]] & sstat %in% c("bias", "empse", "mse", "relprec", "modelse", "relerror", "cover", "bccover", "power")) {
     gg <- gg + ggplot2::geom_errorbar(ggplot2::aes_string(ymin = "lower", ymax = "upper"), width = gpars.ok$width)
