@@ -145,3 +145,12 @@ test_that("multisimsum with x = TRUE returns the original dataset (setting all d
   expect_s3_class(object = s$data, class = "data.frame")
   expect_equal(object = s$data, expected = na.omit(frailty))
 })
+
+test_that("multisimsum with a methodvar not in string format coerce it to string", {
+  data("frailty")
+  s1 <- multisimsum(data = frailty, par = "par", true = c(trt = -0.50, fv = 0.75), estvarname = "b", se = "se", methodvar = "model", by = "fv_dist")
+  frailty[["model"]] <- as.numeric(factor(frailty[["model"]]))
+  s2 <- multisimsum(data = frailty, par = "par", true = c(trt = -0.50, fv = 0.75), estvarname = "b", se = "se", methodvar = "model", by = "fv_dist")
+  expect_true(all(get_data(s1)[["est"]] == get_data(s2)[["est"]]))
+  expect_true(all(na.omit(get_data(s1)[["mcse"]]) == na.omit(get_data(s2)[["mcse"]])))
+})
